## ---- echo = FALSE, message = FALSE-------------------------------------------
library(knitr)
knitr::opts_chunk$set(
    error = FALSE,
    tidy  = FALSE,
    message = FALSE,
    warning = FALSE,
    fig.align = "center")

## -----------------------------------------------------------------------------
library(rGREAT)

## -----------------------------------------------------------------------------
set.seed(123)
gr = randomRegions(nr = 1000, genome = "hg19")
head(gr)

## ---- eval = FALSE------------------------------------------------------------
#  job = submitGreatJob(gr)

## ---- echo = FALSE------------------------------------------------------------
job = readRDS(system.file("extdata", "GreatJob.rds", package = "rGREAT"))

## -----------------------------------------------------------------------------
job

## ---- eval = FALSE------------------------------------------------------------
#  job = submitGreatJob(gr, species = "mm9") # of course, gr should be from mm9
#  job = submitGreatJob(gr, adv_upstream = 10, adv_downstream = 2, adv_span = 2000)
#  job = submitGreatJob(gr, rule = "twoClosest", adv_twoDistance = 2000)
#  job = submitGreatJob(gr, rule = "oneClosest", adv_oneDistance = 2000)

## ---- eval = FALSE------------------------------------------------------------
#  job = submitGreatJob(gr, version = "3.0")
#  job = submitGreatJob(gr, version = "2.0")

## ---- message = TRUE----------------------------------------------------------
tbl = getEnrichmentTables(job)
names(tbl)
tbl[[1]][1:2, ]

## -----------------------------------------------------------------------------
job

## ---- eval = FALSE------------------------------------------------------------
#  tbl = getEnrichmentTables(job, ontology = c("GO Molecular Function", "Human Phenotype"))
#  tbl = getEnrichmentTables(job, category = c("GO"))

## ---- eval = FALSE------------------------------------------------------------
#  tbl2 = getEnrichmentTables(job, download_by = "tsv")

## -----------------------------------------------------------------------------
availableOntologies(job)
availableCategories(job)
availableOntologies(job, category = "GO")

## ---- fig.width = 6, fig.height = 6-------------------------------------------
plotVolcano(job, ontology = "GO Biological Process")

## ---- fig.width = 10, fig.height = 10/3, fig.align = 'center'-----------------
plotRegionGeneAssociations(job)

## -----------------------------------------------------------------------------
getRegionGeneAssociations(job)

## ---- eval = FALSE------------------------------------------------------------
#  plotRegionGeneAssociations(job, which_plot = 1)

## ---- fig.width = 10, fig.height = 10/3---------------------------------------
plotRegionGeneAssociations(job, ontology = "GO Molecular Function",
    term_id = "GO:0004984")
getRegionGeneAssociations(job, ontology = "GO Molecular Function",
    term_id = "GO:0004984")

## ---- eval = FALSE------------------------------------------------------------
#  shinyReport(job)

## -----------------------------------------------------------------------------
sessionInfo()

