## ---- echo = FALSE, message = FALSE-------------------------------------------
library(knitr)
knitr::opts_chunk$set(
    error = FALSE,
    tidy  = FALSE,
    message = FALSE,
    warning = FALSE,
    fig.align = "center")

## -----------------------------------------------------------------------------
library(rGREAT)
rGREAT:::BIOC_ANNO_PKGS$txdb

## ---- eval = FALSE------------------------------------------------------------
#  great(gr, "GO:BP", "galGal6")

## ---- eval = FALSE------------------------------------------------------------
#  great(gr, "GO:BP", "TxDb.Ggallus.UCSC.galGal6.refGene")

## ---- eval = FALSE------------------------------------------------------------
#  # Giant panda
#  great(gr, "GO:BP", biomart_dataset = "amelanoleuca_gene_ensembl")

## -----------------------------------------------------------------------------
library(msigdbr)
msigdbr_species()

## -----------------------------------------------------------------------------
h_gene_sets = msigdbr(species = "chimpanzee", category = "H")
head(h_gene_sets)

## -----------------------------------------------------------------------------
# convert to a list of gene sets
h_gene_sets = split(h_gene_sets$entrez_gene, h_gene_sets$gs_name)
h_gene_sets = lapply(h_gene_sets, as.character)  # just to make sure gene IDs are all in character.
h_gene_sets[1:2]

## ---- eval = FALSE------------------------------------------------------------
#  great(gr, h_gene_sets, "panTro6")

## ---- eval = .Platform$OS.type == "unix"--------------------------------------
genes = getGenomeDataFromNCBI("GCF_011762595.1", return_granges = TRUE)
genes

## ---- eval = .Platform$OS.type == "unix"--------------------------------------
seqlengths(genes)

## ---- eval = FALSE------------------------------------------------------------
#  great(gr, your_go_gene_sets, tss_source = genes, ...)

## ---- eval = .Platform$OS.type == "unix"--------------------------------------
lt = getGenomeDataFromNCBI("GCF_011762595.1", return_granges = FALSE)
names(lt)

## ---- eval = .Platform$OS.type == "unix"--------------------------------------
head(lt$genome)
head(lt$gene)

## ---- eval = .Platform$OS.type == "unix"--------------------------------------
map = structure(lt$genome$genbankAccession, names = lt$genome$refseqAccession)
head(map)

## ---- eval = .Platform$OS.type == "unix"--------------------------------------
genes = lt$gene
genes[, 1] = map[ genes[, 1] ]
genes = genes[!is.na(genes[, 1]), ]
genes = GRanges(seqnames = genes[, 1], ranges = IRanges(genes[, 2], genes[, 3]),
                strand = genes[, 4], gene_id = genes[, 5])

## ---- eval = .Platform$OS.type == "unix"--------------------------------------
sl = structure(lt$genome$length, names = lt$genome$genbankAccession)
sl = sl[!is.na(names(sl))]
seqlengths(genes) = sl
genes

## ---- eval = FALSE------------------------------------------------------------
#  great(gr, your_go_gene_sets, tss_source = genes, ...)

## -----------------------------------------------------------------------------
getKEGGGenome("mgp")

